@@ -6,7 +6,7 @@
  *
  * @package WordPress
  * @subpackage Twenty_Seventeen
- * @since 1.0
+ * @since Twenty Seventeen 1.0
  * @version 1.0
  */
 
@@ -31,4 +31,5 @@ get_header(); ?>
 	</div><!-- #primary -->
 </div><!-- .wrap -->
 
-<?php get_footer();
+<?php
+get_footer();
