@@ -15,7 +15,6 @@
  * core WordPress functions pass this class in the event of an error and
  * if not handled properly will result in code errors.
  *
- * @package WordPress
  * @since 2.1.0
  */
 class WP_Error {
@@ -48,48 +47,50 @@ class WP_Error {
 	 *
 	 * @since 2.1.0
 	 *
-	 * @param string|int $code Error code
-	 * @param string $message Error message
-	 * @param mixed $data Optional. Error data.
+	 * @param string|int $code    Error code.
+	 * @param string     $message Error message.
+	 * @param mixed      $data    Optional. Error data.
 	 */
 	public function __construct( $code = '', $message = '', $data = '' ) {
-		if ( empty($code) )
+		if ( empty( $code ) ) {
 			return;
+		}
 
-		$this->errors[$code][] = $message;
+		$this->errors[ $code ][] = $message;
 
-		if ( ! empty($data) )
-			$this->error_data[$code] = $data;
+		if ( ! empty( $data ) ) {
+			$this->error_data[ $code ] = $data;
+		}
 	}
 
 	/**
 	 * Retrieve all error codes.
 	 *
 	 * @since 2.1.0
-	 * @access public
 	 *
 	 * @return array List of error codes, if available.
 	 */
 	public function get_error_codes() {
-		if ( empty($this->errors) )
+		if ( ! $this->has_errors() ) {
 			return array();
+		}
 
-		return array_keys($this->errors);
+		return array_keys( $this->errors );
 	}
 
 	/**
 	 * Retrieve first error code available.
 	 *
 	 * @since 2.1.0
-	 * @access public
 	 *
 	 * @return string|int Empty string, if no error codes.
 	 */
 	public function get_error_code() {
 		$codes = $this->get_error_codes();
 
-		if ( empty($codes) )
+		if ( empty( $codes ) ) {
 			return '';
+		}
 
 		return $codes[0];
 	}
@@ -102,20 +103,22 @@ class WP_Error {
 	 * @param string|int $code Optional. Retrieve messages matching code, if exists.
 	 * @return array Error strings on success, or empty array on failure (if using code parameter).
 	 */
-	public function get_error_messages($code = '') {
+	public function get_error_messages( $code = '' ) {
 		// Return all messages if no code specified.
-		if ( empty($code) ) {
+		if ( empty( $code ) ) {
 			$all_messages = array();
-			foreach ( (array) $this->errors as $code => $messages )
-				$all_messages = array_merge($all_messages, $messages);
+			foreach ( (array) $this->errors as $code => $messages ) {
+				$all_messages = array_merge( $all_messages, $messages );
+			}
 
 			return $all_messages;
 		}
 
-		if ( isset($this->errors[$code]) )
-			return $this->errors[$code];
-		else
+		if ( isset( $this->errors[ $code ] ) ) {
+			return $this->errors[ $code ];
+		} else {
 			return array();
+		}
 	}
 
 	/**
@@ -129,12 +132,14 @@ class WP_Error {
 	 * @param string|int $code Optional. Error code to retrieve message.
 	 * @return string
 	 */
-	public function get_error_message($code = '') {
-		if ( empty($code) )
+	public function get_error_message( $code = '' ) {
+		if ( empty( $code ) ) {
 			$code = $this->get_error_code();
-		$messages = $this->get_error_messages($code);
-		if ( empty($messages) )
+		}
+		$messages = $this->get_error_messages( $code );
+		if ( empty( $messages ) ) {
 			return '';
+		}
 		return $messages[0];
 	}
 
@@ -146,28 +151,44 @@ class WP_Error {
 	 * @param string|int $code Optional. Error code.
 	 * @return mixed Error data, if it exists.
 	 */
-	public function get_error_data($code = '') {
-		if ( empty($code) )
+	public function get_error_data( $code = '' ) {
+		if ( empty( $code ) ) {
 			$code = $this->get_error_code();
+		}
 
-		if ( isset($this->error_data[$code]) )
-			return $this->error_data[$code];
+		if ( isset( $this->error_data[ $code ] ) ) {
+			return $this->error_data[ $code ];
+		}
+	}
+
+	/**
+	 * Verify if the instance contains errors.
+	 *
+	 * @since 5.1.0
+	 *
+	 * @return bool
+	 */
+	public function has_errors() {
+		if ( ! empty( $this->errors ) ) {
+			return true;
+		}
+		return false;
 	}
 
 	/**
 	 * Add an error or append additional message to an existing error.
 	 *
 	 * @since 2.1.0
-	 * @access public
 	 *
-	 * @param string|int $code Error code.
-	 * @param string $message Error message.
-	 * @param mixed $data Optional. Error data.
+	 * @param string|int $code    Error code.
+	 * @param string     $message Error message.
+	 * @param mixed      $data    Optional. Error data.
 	 */
-	public function add($code, $message, $data = '') {
-		$this->errors[$code][] = $message;
-		if ( ! empty($data) )
-			$this->error_data[$code] = $data;
+	public function add( $code, $message, $data = '' ) {
+		$this->errors[ $code ][] = $message;
+		if ( ! empty( $data ) ) {
+			$this->error_data[ $code ] = $data;
+		}
 	}
 
 	/**
@@ -177,14 +198,15 @@ class WP_Error {
 	 *
 	 * @since 2.1.0
 	 *
-	 * @param mixed $data Error data.
+	 * @param mixed      $data Error data.
 	 * @param string|int $code Error code.
 	 */
-	public function add_data($data, $code = '') {
-		if ( empty($code) )
+	public function add_data( $data, $code = '' ) {
+		if ( empty( $code ) ) {
 			$code = $this->get_error_code();
+		}
 
-		$this->error_data[$code] = $data;
+		$this->error_data[ $code ] = $data;
 	}
 
 	/**
@@ -202,17 +224,3 @@ class WP_Error {
 		unset( $this->error_data[ $code ] );
 	}
 }
-
-/**
- * Check whether variable is a WordPress Error.
- *
- * Returns true if $thing is an object of the WP_Error class.
- *
- * @since 2.1.0
- *
- * @param mixed $thing Check if unknown variable is a WP_Error object.
- * @return bool True, if WP_Error. False, if not WP_Error.
- */
-function is_wp_error( $thing ) {
-	return ( $thing instanceof WP_Error );
-}
